summaryrefslogtreecommitdiff
path: root/board/evb4510
diff options
context:
space:
mode:
authorwdenk <wdenk>2005-04-02 23:52:25 +0000
committerwdenk <wdenk>2005-04-02 23:52:25 +0000
commit400558b561e2bdb47f87b96b3510dda0881a3662 (patch)
tree479fa3918e0031a95cdac9468cb8396e1f1a9b60 /board/evb4510
parent414eec35e3832f4f9ce8a25ace7ead638be1f76f (diff)
Prepare for SoC rework of ARM code:
- rename CONFIG_BOOTBINFUNC into CONFIG_INIT_CRITICAL - rename memsetup into lowlevel_init (function name and source files)
Diffstat (limited to 'board/evb4510')
-rw-r--r--board/evb4510/Makefile2
-rw-r--r--board/evb4510/lowlevel_init.S (renamed from board/evb4510/memsetup.S)6
2 files changed, 4 insertions, 4 deletions
diff --git a/board/evb4510/Makefile b/board/evb4510/Makefile
index 1ab4dfb36..10850a95e 100644
--- a/board/evb4510/Makefile
+++ b/board/evb4510/Makefile
@@ -26,7 +26,7 @@ include $(TOPDIR)/config.mk
LIB = lib$(BOARD).a
OBJS := evb4510.o flash.o
-SOBJS := memsetup.o
+SOBJS := lowlevel_init.o
$(LIB): $(OBJS) $(SOBJS)
$(AR) crv $@ $^
diff --git a/board/evb4510/memsetup.S b/board/evb4510/lowlevel_init.S
index 915af1e9e..7184d7259 100644
--- a/board/evb4510/memsetup.S
+++ b/board/evb4510/lowlevel_init.S
@@ -31,7 +31,7 @@
*
* This memory map allows us to relocate from FLASH to SRAM. After
* power-on reset the CPU only knows about the FLASH memory at address
* 0x00000000. After memsetup completes the memory map will be:
*
* Memory Addr
* 0x00000000
@@ -54,8 +54,8 @@
*
***********************************************************************/
-.globl memsetup
-memsetup:
+.globl lowlevel_init
+lowlevel_init:
/* preserve the temp register (r12 AKA ip) and remap it. */
ldr r1, =SRAM_BASE+0xC
@@ -31,7 +31,7 @@
* This memory map allows us to relocate from FLASH to SRAM. After
* power-on reset the CPU only knows about the FLASH memory at address
- * 0x00000000. After memsetup completes the memory map will be:
+ * 0x00000000. After lowlevel_init completes the memory map will be:
*
* Memory Addr